/*
 * @Author: heinan
 * @Date: 2021-04-26 09:17:38
 * @Last Modified by: heinan
 * @Last Modified time: 2021-04-26 14:37:08
 */

import axios from "axios";
import { message } from "antd";
import { getSession } from "@/utils";
import router from "umi/router";

const request = axios.create();

request.interceptors.request.use(
  config => {
    config.headers = {
      ...config.headers,
      Authorization: getSession("token") || ""
    };
    return config;
  },
  error => {
    return Promise.reject(error);
  }
);
request.interceptors.response.use(
  response => {
    return response;
  },
  error => {
    const status = error.response.status;
    switch (status) {
      case 200:
        break;
      case 401:
        return message.error({
          content: error.response.data.msg,
          duration: 2,
          onClose() {
            router.replace("/login");
          }
        });
      default:
        message.warning(error.response.data.msg);
        break;
    }
    return Promise.reject(error);
  }
);

export default request;
